async fn submit_delegate(
service: &SafeServiceOpts,
rpc: &RpcOpts,
wallet: &WalletOpts,
safe: Address,
delegate: Address,
method: Method,
path: &str,
body: Value,
) -> Result<()>Expand description
Signs the delegate TOTP message with the wallet and submits body (extended with the Safe,
delegator and signature) to the Transaction Service, printing the delegate on success.